@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhinit.pl 2.25 01/08/26 02:19:52
+##	$Id: mhinit.pl,v 2.29 2001/10/06 13:59:44 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -175,6 +175,7 @@ sub mhinit_vars {
 
 ##	Message information variables
 
+$NewMsgCnt	=  0;	# Total number of new messages
 $NumOfMsgs	=  0;	# Total number of messages
 $LastMsgNum	= -1;	# Message number of last message
 %Message  	= ();	# Message indexes to bodies
@@ -298,10 +299,7 @@ $DBPathName	= '';	# Full pathname of database file
 %readmail::MIMEFiltersArgs = (
     # Content-type			Arguments
     #-------------------------------------------------------------------
-    "image/gif",			"inline",
-    "image/jpeg",			"inline",
-    "image/x-xbitmap", 	 		"inline",
-    "image/x-xbm",			"inline",
+    'm2h_external::filter',		'inline',
 );
 
 ##  Charset filters
@@ -328,6 +326,8 @@ $DBPathName	= '';	# Full pathname of database file
     "latin4",   			"MHonArc::CharEnt::str2sgml",
     "latin5",   			"MHonArc::CharEnt::str2sgml",
     "latin6",   			"MHonArc::CharEnt::str2sgml",
+    "windows-1250",   			"MHonArc::CharEnt::str2sgml",
+    "windows-1252",   			"MHonArc::CharEnt::str2sgml",
     "default",     			"-ignore-",
 );
 %readmail::MIMECharSetConvertersSrc = (
@@ -352,6 +352,8 @@ $DBPathName	= '';	# Full pathname of database file
     "latin4",   			"MHonArc/CharEnt.pm",
     "latin5",   			"MHonArc/CharEnt.pm",
     "latin6",   			"MHonArc/CharEnt.pm",
+    "windows-1250",   			"MHonArc/CharEnt.pm",
+    "windows-1252",   			"MHonArc/CharEnt.pm",
     "default",     			undef,
 );
 
@@ -376,7 +378,7 @@ $ANNOTATE  = $ENV{'M2H_ANNOTATE'}   || 0;
 $DBFILE    = $ENV{'M2H_DBFILE'}     || 
 	     (($MSDOS || $VMS) ? "mhonarc.db": ".mhonarc.db");
 $DOCURL    = $ENV{'M2H_DOCURL'}     ||
-	     'http://www.oac.uci.edu/indiv/ehood/mhonarc.html';
+	     'http://www.mhonarc.org/';
 $IDXNAME   = "";	# Set in get_resources()
 $IDXPREFIX = $ENV{'M2H_IDXPREFIX'}  || "mail";
 $TIDXPREFIX= $ENV{'M2H_TIDXPREFIX'} || "thrd";
@@ -394,6 +396,8 @@ $LOCKTRIES = $ENV{'M2H_LOCKTRIES'}  || 10;
 $LOCKDELAY = $ENV{'M2H_LOCKDELAY'}  || 3;
 $MAXSIZE   = $ENV{'M2H_MAXSIZE'}    || 0;
 $TLEVELS   = $ENV{'M2H_TLEVELS'}    || 3;
+$TSLICELEVELS =
+	     $ENV{'M2H_TSLICELEVELS'} || -1;
 $MHPATTERN = $ENV{'M2H_MHPATTERN'}  || '^\d+$';
 $DefRcFile = $ENV{'M2H_DEFRCFILE'}  || '';
 $HtmlExt   = $ENV{'M2H_HTMLEXT'}    || "html";
