@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcvars.pl 2.14 01/08/26 02:25:22
+##	$Id: mhrcvars.pl,v 2.17 2002/04/18 06:12:39 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -155,21 +155,23 @@ sub replace_li_var {
 	}
     	if ($var eq 'ICON') {		## Message icon
 	    ($lref, $key, $pos) = compute_msg_pos($index, $var, $arg);
-	    if (!defined($key)) { $tmp = ""; last REPLACESW; }
-	    $tmp = $Icons{$ContentType{$key}} ?
-			join("", qq|<img src="$Icons{$ContentType{$key}}" |,
-			     qq|alt="[$ContentType{$key}]">|) :
-			qq|<img src="$Icons{'unknown'}" alt="[unknown]">|;
+	    if (!defined($key)) {
+		$tmp = "";
+		last REPLACESW;
+	    }
+	    my($iconurl, $iw, $ih) = mhonarc::get_icon_url($ContentType{$key});
+	    my $alttext = $iconurl ? $ContentType{$key} : 'unknown';
+	    $tmp  = qq|<img src="$iconurl" border="0" alt="[$alttext]"|;
+	    $tmp .= ' width="' .  $iw . '"'  if $iw;
+	    $tmp .= ' height="' . $ih . '"'  if $ih;
+	    $tmp .= '>';
 	    last REPLACESW;
 	}
     	if ($var eq 'ICONURL') {	## URL to message icon
 	    $isurl = 0;
-	    ($lref, $key, $pos) = compute_msg_pos($index, $var, $arg);
-	    if ($Icons{$ContentType{$key}}) {
-		$tmp = $Icons{$ContentType{$key}};
-	    } else {
-		$tmp = $Icons{'unknown'};
-	    }
+	    ($lref, $key, $pos)    = compute_msg_pos($index, $var, $arg);
+	    my($iconurl, $iw, $ih) = mhonarc::get_icon_url($ContentType{$key});
+	    $tmp = $iconurl  if defined($iconurl);
 	    last REPLACESW;
 	}
     	if ($var eq 'MSG') {		## Filename of message page
@@ -185,7 +187,7 @@ sub replace_li_var {
 	}
     	if ($var eq 'MSGID') {		## Message-ID
 	    ($lref, $key, $pos) = compute_msg_pos($index, $var, $arg);
-	    $tmp = defined($key) ? $Index2MsgId{$index} : "";
+	    $tmp = defined($key) ? $Index2MsgId{$key} : "";
 	    last REPLACESW;
 	}
     	if ($var eq 'MSGLOCALDATE') {	## Message local date
@@ -261,6 +263,11 @@ sub replace_li_var {
 	    }
 	    last REPLACESW;
 	}
+    	if ($var eq 'TLEVEL') {		## Thread level
+	    ($lref, $key, $pos) = compute_msg_pos($index, $var, $arg);
+	    $tmp = $ThreadLevel{$key};
+	    last REPLACESW;
+	}
 
 	## ------------------------------------- ##
 	## Message navigation resource variables ##
@@ -625,8 +632,18 @@ sub replace_li_var {
 	}
 
 	# Check for clipping
-	$ret = join("", ($ret =~ /(\&[^;\s]*;|.)/g)[0 .. $len - 1])
-	    if ($len > 0 && $canclip);
+	if ($len > 0 && $canclip && (length($ret) > 0)) {
+	    if ($ret =~ /\&/) {
+		my @chars = $ret =~ /(\&[^;\s]*;|.)/g;
+		if (scalar(@chars) < $len) {
+		    $ret = join('', @chars);
+		} else {
+		    $ret = join('', @chars[0 .. $len-1])
+		}
+	    } else {
+		$ret = substr($ret, 0, $len);
+	    }
+	}
 
 	# Check if JavaScript string
 	if ($jstr) {
@@ -691,7 +708,7 @@ sub compute_msg_pos {
 	}
 
 	$ofs =  0, last SW
-	    if $arg eq "" or $arg eq 'CUR';
+	    if (!defined($arg)) || ($arg eq '') || ($arg eq 'CUR');
 	$ofs = ($flip ? -$arg : $arg), last SW
 	    if $arg =~ /^-?\d+$/;
 
@@ -718,10 +735,12 @@ sub compute_msg_pos {
 	    }
 	    # get here, it is thread and reverse
 	    undef $ofs;
-	    $pos = $href->{$idx};
-	    if (($pos > 0) && ($ThreadLevel{$aref->[$pos-1]} > 0)) {
-		--$pos;
-		last SW;
+	    if ($ThreadLevel{$idx} > 0) {
+		$pos = $href->{$idx};
+		if (($pos > 0) && ($ThreadLevel{$aref->[$pos-1]} >= 0)) {
+		    --$pos;
+		    last SW;
+		}
 	    }
 	    # get here, must goto physical next top
 	    # note no `last SW' statement
